@@ -79,7 +79,7 @@ static gnutls_error_entry error_algorithms[] = {
 	GNUTLS_ERROR_ENTRY( GNUTLS_E_COMPRESSION_FAILED, 1),
 	GNUTLS_ERROR_ENTRY( GNUTLS_E_MEMORY_ERROR, 1),
 	GNUTLS_ERROR_ENTRY( GNUTLS_E_UNIMPLEMENTED_FEATURE, 1),
-	GNUTLS_ERROR_ENTRY( GNUTLS_E_INSUFICIENT_CRED, 1),
+	GNUTLS_ERROR_ENTRY( GNUTLS_E_INSUFICIENT_CREDENTIALS, 1),
 	GNUTLS_ERROR_ENTRY( GNUTLS_E_PWD_ERROR, 1),
 	GNUTLS_ERROR_ENTRY( GNUTLS_E_PKCS1_WRONG_PAD, 1),
 	GNUTLS_ERROR_ENTRY( GNUTLS_E_EXPIRED, 1),
