@@ -32,7 +32,9 @@
 #define GNUTLS_E_EXPIRED -29
 #define GNUTLS_E_DB_ERROR -30
 #define GNUTLS_E_PWD_ERROR -31
-#define GNUTLS_E_INSUFICIENT_CRED -32
+#define GNUTLS_E_INSUFICIENT_CREDENTIALS -32
+#define GNUTLS_E_INSUFICIENT_CRED GNUTLS_E_INSUFICIENT_CREDENTIALS
+
 #define GNUTLS_E_HASH_FAILED -33
 #define GNUTLS_E_PARSING_ERROR -34
 #define	GNUTLS_E_MPI_PRINT_FAILED -35
@@ -85,6 +87,10 @@
 #define GNUTLS_E_INIT_LIBEXTRA -82
 #define GNUTLS_E_LIBRARY_VERSION_MISMATCH -82
 #define GNUTLS_E_EXPORT_CIPHER_SUITE -83
+
+/* returned if you need to generate temporary RSA 
+ * parameters. These are needed for export cipher suites.
+ */
 #define GNUTLS_E_NO_TEMPORARY_RSA_PARAMS -84
 
 #define GNUTLS_E_UNIMPLEMENTED_FEATURE -250
