@@ -42,8 +42,6 @@
  */
 typedef int gnutls_transport_ptr;
 
-typedef const int* gnutls_list;
-
 #define MIN_BITS 767
 
 #define MAX32 4294967295
@@ -58,13 +56,18 @@ typedef const int* gnutls_list;
 #define TLS_RANDOM_SIZE 32
 #define TLS_MAX_SESSION_ID_SIZE 32
 #define TLS_MASTER_SIZE 48
+
+/* The maximum digest size of hash algorithms. 
+ */
 #define MAX_HASH_SIZE 20
 
 #define MAX_X509_CERT_SIZE 10*1024
 #define MAX_LOG_SIZE 1024 /* maximum number of log message */
 #define MAX_SRP_USERNAME 256
 
-#define MAX_EXT_TYPES 16
+/* we can receive up to MAX_EXT_TYPES extensions.
+ */
+#define MAX_EXT_TYPES 64
 
 /* The initial size of the receive
  * buffer size. This will grow if larger
@@ -524,9 +527,9 @@ typedef struct {
 	/* holds the extensions we sent to the peer
 	 * (in case of a client)
 	 */
-	uint8			extensions_sent[MAX_EXT_TYPES];
-	uint8			extensions_sent_size;
-	
+	uint16			extensions_sent[MAX_EXT_TYPES];
+	uint16			extensions_sent_size;
+
 	/* is 0 if we are to send the whole PGP key, or non zero
 	 * if the fingerprint is to be sent.
 	 */
