@@ -28,10 +28,11 @@ typedef struct {
 	char email[GNUTLS_X509_CN_SIZE];
 } gnutls_openpgp_name;	
 
-typedef enum GNUTLS_X509_SUBJECT_ALT_NAME {
+typedef enum gnutls_x509_subject_alt_name {
 	GNUTLS_SAN_DNSNAME=1, GNUTLS_SAN_RFC822NAME,
 	GNUTLS_SAN_URI, GNUTLS_SAN_IPADDRESS
-} GNUTLS_X509_SUBJECT_ALT_NAME;
+} gnutls_x509_subject_alt_name;
+#define GNUTLS_X509_SUBJECT_ALT_NAME gnutls_x509_subject_alt_name
 
 /* For key Usage, test as:
  * if (st.keyUsage & X509KEY_DIGITAL_SIGNATURE) ...
@@ -49,34 +50,34 @@ typedef enum GNUTLS_X509_SUBJECT_ALT_NAME {
 
 # ifdef LIBGNUTLS_VERSION /* These are defined only in gnutls.h */
 
-typedef int gnutls_certificate_client_select_function(GNUTLS_STATE, const gnutls_datum *, int, const gnutls_datum *, int);
-typedef int gnutls_certificate_server_select_function(GNUTLS_STATE, const gnutls_datum *, int);
+typedef int gnutls_certificate_client_select_function(gnutls_session, const gnutls_datum *, int, const gnutls_datum *, int);
+typedef int gnutls_certificate_server_select_function(gnutls_session, const gnutls_datum *, int);
 #define gnutls_certificate_client_select_func gnutls_certificate_client_select_function
 #define gnutls_certificate_server_select_func gnutls_certificate_server_select_function
 
 /* Functions that allow AUTH_INFO structures handling
  */
 
-GNUTLS_CredType gnutls_auth_get_type( GNUTLS_STATE state);
+gnutls_credentials_type gnutls_auth_get_type( gnutls_session session);
 
 /* DH */
 
-void gnutls_dh_set_prime_bits( GNUTLS_STATE state, int bits);
-int gnutls_dh_get_prime_bits( GNUTLS_STATE);
-int gnutls_dh_get_secret_bits( GNUTLS_STATE);
-int gnutls_dh_get_peers_public_bits( GNUTLS_STATE);
+void gnutls_dh_set_prime_bits( gnutls_session session, int bits);
+int gnutls_dh_get_prime_bits( gnutls_session);
+int gnutls_dh_get_secret_bits( gnutls_session);
+int gnutls_dh_get_peers_public_bits( gnutls_session);
 
 /* RSA */
-int gnutls_rsa_export_get_modulus_bits(GNUTLS_STATE state);
+int gnutls_rsa_export_get_modulus_bits(gnutls_session session);
 
 /* X509PKI */
 
-void gnutls_certificate_client_set_select_function( GNUTLS_STATE, gnutls_certificate_client_select_function *);
-void gnutls_certificate_server_set_select_function( GNUTLS_STATE, gnutls_certificate_server_select_function *);
+void gnutls_certificate_client_set_select_function( gnutls_session, gnutls_certificate_client_select_function *);
+void gnutls_certificate_server_set_select_function( gnutls_session, gnutls_certificate_server_select_function *);
 #define gnutls_certificate_client_set_select_func gnutls_certificate_client_set_select_function
 #define gnutls_certificate_server_set_select_func gnutls_certificate_server_set_select_function
 
-void gnutls_certificate_server_set_request( GNUTLS_STATE, GNUTLS_CertificateRequest);
+void gnutls_certificate_server_set_request( gnutls_session, gnutls_certificate_request);
 
 /* X.509 certificate handling functions */
 int gnutls_x509_certificate_to_xml(const gnutls_datum * cert, gnutls_datum* res, int detail);
@@ -95,21 +96,21 @@ int gnutls_x509_extract_certificate_pk_algorithm( const gnutls_datum * cert, int
 int gnutls_x509_verify_certificate( const gnutls_datum* cert_list, int cert_list_length, const gnutls_datum * CA_list, int CA_list_length, const gnutls_datum* CRL_list, int CRL_list_length);
 
 
-/* get data from the state */
-const gnutls_datum* gnutls_certificate_get_peers( GNUTLS_STATE, int* list_size);
-const gnutls_datum *gnutls_certificate_get_ours( GNUTLS_STATE state);
+/* get data from the session */
+const gnutls_datum* gnutls_certificate_get_peers( gnutls_session, int* list_size);
+const gnutls_datum *gnutls_certificate_get_ours( gnutls_session session);
 
-time_t gnutls_certificate_activation_time_peers(GNUTLS_STATE state);
-time_t gnutls_certificate_expiration_time_peers(GNUTLS_STATE state);
+time_t gnutls_certificate_activation_time_peers(gnutls_session session);
+time_t gnutls_certificate_expiration_time_peers(gnutls_session session);
 
-int gnutls_certificate_client_get_request_status(  GNUTLS_STATE);
-int gnutls_certificate_verify_peers( GNUTLS_STATE);
+int gnutls_certificate_client_get_request_status(  gnutls_session);
+int gnutls_certificate_verify_peers( gnutls_session);
 
-int gnutls_b64_encode_fmt( const char* msg, const gnutls_datum *data, char* result, int* result_size);
-int gnutls_b64_decode_fmt( const gnutls_datum *b64_data, char* result, int* result_size);
+int gnutls_pem_base64_encode( const char* header, const gnutls_datum *data, char* result, int* result_size);
+int gnutls_pem_base64_decode( const char* header, const gnutls_datum *b64_data, char* result, int* result_size);
 
-int gnutls_b64_encode_fmt2( const char* msg, const gnutls_datum *data, const gnutls_datum * result);
-int gnutls_b64_decode_fmt2( const gnutls_datum *b64_data, const gnutls_datum* result);
+int gnutls_pem_base64_encode_alloc( const char* header, const gnutls_datum *data, const gnutls_datum * result);
+int gnutls_pem_base64_decode_alloc( const char* header, const gnutls_datum *b64_data, const gnutls_datum* result);
 
 # endif /* LIBGNUTLS_VERSION */
 
